@@ -10,8 +10,8 @@ import pandas as pd
 import unyts
 
 
-__version__ = '0.1.1'
-__release__ = 20230202
+__version__ = '0.1.3'
+__release__ = 20230219
 __all__ = ['Log']
 
 
@@ -29,35 +29,10 @@ class Log(object, metaclass=Log2FrameType):
         self.source = source
         self.uwi = self.header['UWI'] if 'UWI' in self.header else None
         if well is None:
-            self.well = self.header['WN'] if 'WN' in self.header else self.header['WELL'] if 'WELL' in self.header else None
+            self.well = self.header['WN'] if 'WN' in self.header else self.header['WELL'] if 'WELL' in self.header else self.uwi
         else:
             self.well = well
 
-    def keys(self):
-        return self.data.columns
-
-    @property
-    def columns(self):
-        return self.keys()
-
-    @property
-    def curves(self):
-        return self.keys()
-
-    @property
-    def meta(self):
-        return self.header
-
-    def copy(self):
-        return Log(data=self.data.copy(),
-                   header=self.header.copy(),
-                   units=self.units.copy(),
-                   source=self.source,
-                   well=self.well)
-
-    def __copy__(self):
-        return self.copy()
-
     def __add__(self, other):
         from .pack import Pack
         if isinstance(other, Pack):
@@ -70,14 +45,11 @@ class Log(object, metaclass=Log2FrameType):
         else:
             raise NotImplementedError("Addition of Log and '" + str(type(other)) + "' is not implemented.")
 
-    def __len__(self):
-        return len(self.data)
+    def __contains__(self, curve):
+        return curve in self.data or curve == self.index_name
 
-    def __repr__(self):
-        return self.data.__repr__()
-
-    def _repr_html_(self):
-        return self.data._repr_html_()
+    def __copy__(self):
+        return self.copy()
 
     def __getitem__(self, mnemonics):
         try:
@@ -91,27 +63,56 @@ class Log(object, metaclass=Log2FrameType):
                 except:
                     raise KeyError("'" + str(mnemonics) + "' is not a curve name and is not a value in the index.")
 
-    def __setitem__(self, mnemonics, curve):
-        self.data[mnemonics] = curve
-
-    def __contains__(self, curve):
-        return curve in self.data or curve == self.index_name
-
     def __iter__(self):
         return self
 
+    def __len__(self):
+        return len(self.data)
+
     def __next__(self):
         for curve in self.data.columns:
             yield curve
 
+    def __repr__(self):
+        return self.data.__repr__()
+
+    def _repr_html_(self):
+        return self.data._repr_html_()
+
+    def __setitem__(self, mnemonics, curve):
+        self.data[mnemonics] = curve
+
+    @property
+    def columns(self):
+        return self.keys()
+
+    def copy(self):
+        return Log(data=self.data.copy(),
+                   header=self.header.copy(),
+                   units=self.units.copy(),
+                   source=self.source,
+                   well=self.well)
+
+    @property
+    def curves(self):
+        return self.keys()
+
     @property
     def index(self):
         return self.data.index
 
+    @index.setter
+    def index(self, index):
+        self.data.index = index
+
     @property
     def index_name(self):
         return self.data.index.name
 
+    @index_name.setter
+    def index_name(self, name):
+        self.data.index.name = name
+
     @property
     def index_units(self):
         if hasattr(self.data, 'index_units'):
@@ -121,6 +122,24 @@ class Log(object, metaclass=Log2FrameType):
         else:
             logging.warning("index units are not defined.")
 
+    @index_units.setter
+    def index_units(self, units: str):
+        self.set_index_units(units)
+
+    def keys(self):
+        return self.data.columns
+
+    @property
+    def meta(self):
+        return self.header
+
+    @property
+    def path(self):
+        return self.source
+
+    def set_index_name(self, name):
+        self.data.index.name = name
+
     def set_index_units(self, units: str):
         if hasattr(self.data, 'set_index_units'):
             self.data.set_index_units(units)
@@ -180,6 +199,23 @@ class Log(object, metaclass=Log2FrameType):
                 logging.warning(msg)
             return self
 
+    @property
+    def name(self):
+        if self.uwi is not None:
+            return self.uwi
+        elif self.well is not None:
+            return self.well
+
+    @name.setter
+    def name(self, new_name: str):
+        self.rename(new_name)
+
+    def rename(self, new_name: str):
+        new_name = str(new_name).strip()
+        self.well = new_name
+        if hasattr(self.data, "name"):
+            self.data.name = new_name
+
     def set_index(self, curve, inplace=False):
         inplace = bool(inplace)
         if curve == self.index_name:
@@ -203,13 +239,6 @@ class Log(object, metaclass=Log2FrameType):
             else:
                 logging.warning(msg)
 
-    @property
-    def name(self):
-        if self.uwi is not None:
-            return self.uwi
-        elif self.well is not None:
-            return self.well
-
     def to(self, units, curve=None):
         if curve is not None:
             if type(curve) is str and type(units) is str:
